#include "stock.h"

#include <unistd.h>
#include <stdlib.h>
#include <getopt.h>

extern char *optarg;
extern int optind, opterr, optopt;

void init_defaults () {
   
   if ((logfile = fopen ("./stock.log", "w+")) == NULL) {
      printf ("Can't open file for keeping logs\n");
      exit (1);
   }
   
   ok='c';
   err='e'; 
   
   portnum = 5000;
   
   max_players = 50;
   max_simult_players = 20;
   max_len_player_name = 16;
   
   initial_cash = 100000;
   max_simult_quot = 4;
   last_quot = max_simult_quot - 1;
   max_history = 10;
   
   resize = 8;
   punish_interval = 10;
   admin_interval = 10;
   hashsize = 1 + max_companies / 8;
   tolerance = 1;
   timeout = 10;  /* in units of admin_interval */
   
   player = (player_t *) xmalloc (resize * sizeof(player_t));
   company = NULL;
}

void parse_options (int ac, char *av[]) {
   char *optstring="p:s:l:c:q:r:u:a:t:i:y:m:h";
   int opt;
   char *help[] = {  
      "Stock Server : Viral <viralbs@giasbma.vsnl.net.in>",
      "version : 0.60",
      "",
      "command-line options :",
      "-p <n>\tPort that server listens to. Only give the first one. (5000)",
      "-c <n>\tMaximum number of players (50)",
      "-s <n>\tMaximum simultaneous players (20)",
      "-l <n>\tMaximum length of a player's name to be stored (trivial) (16)",
      "-m <n>\tInitial money that each new player starts out with (100000)",
      "-q <n>\tMaximum quotations allowed per buy/sell list of a company (4)",
      "-h \tPrint this help",
      "-r <n>\tUse this resize value while resizing internal lists (8)",
      "-a <n>\tSet administration interval, used for cleaner and news threads (10)",
      "-y <n>\tNo. of last trades to remember per company (10)",
      "-t <n>\tTolerance in prices while trading (1)",
      "-i <n>\tIdle time for kicking a player in units of admin_interval (10)",
      "",
      NULL
   };
   
   while (1) {
      if ((opt = getopt (ac, av, optstring)) == -1) break;
      
      switch (opt) {
	 register int i;
	 
       case 'p':
	 portnum = atoi (optarg);
	 break;
	 
       case 'c':
	 max_players = atoi (optarg);
	 break;
	 
       case 's':
	 max_simult_players = atoi (optarg);
	 break;
	 
       case 'l':
	 max_len_player_name = (short) atoi (optarg);
	 break;
	 
       case 'm':
	 initial_cash = atoi (optarg);
	 break;
	 
       case 'q':
	 max_simult_quot = atoi (optarg);
	 break;
	 
       case 'y':
	 max_history = atoi (optarg);
	 break;
	 
       case 'r':
	 resize = atoi (optarg);
	 break;
	 
       case 'u':
	 punish_interval = atoi (optarg);
	 break;
	 
       case 'a':
	 admin_interval = atoi (optarg);
	 break;
	 
       case 'h':
	 for (i=0; help[i] != NULL; ++i) 
	   printf ("%s\n", help[i]);
	 exit (0);
	 
       case 't':
	 tolerance = atoi (optarg);
	 break;
	 
       case 'i':
	 timeout = atoi (optarg);
	 break;
      
      } /* switch (opt)  */
   } /* while (1) ... */
} /* parse_options () ... */
